==> breeze_website_builder_6.1.20.tar.gz: manage/plugins/lang/gallery/en.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Manage Lightbox Gallary Parameters");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Manage Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Height");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Image Width");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Height");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Show Titles");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "Delete Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Click 'Update' to publish<br />your uploaded images.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "All images have been resized and settings have been saved.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "There was an error resizing the images or saving settings.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Your image(s) has been uploaded.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "There was an error uploading your image(s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "The file you are trying to upload is not an image.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "The file you are trying to upload is too big.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "The title has been saved.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Are you sure you want to delete image");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "The image has been deleted.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "There was an error deleting the image.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Saving parameters and resizing images, please wait...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, please wait...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "The sort order has not been saved. Do you want to save the sort order?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "The image sort order has been saved.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "There was an error saving the image sort.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/en.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Manage Lightbox Gallary Parameters");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Manage Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Height");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Image Width");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Image Height");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Preserve Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Show Titles");
define('MANAGE_GALLERY_DISABLE_SORT', "Disable Sort");
define('MANAGE_GALLERY_DELETE_IMAGE', "Delete Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Save Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Click 'Update' to publish<br />your uploaded images.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "All images have been resized and settings have been saved.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "There was an error resizing the images or saving settings.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Your image(s) has been uploaded.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "There was an error uploading your image(s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "The file you are trying to upload is not an image.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "The file you are trying to upload is too big.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "The title has been saved.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Are you sure you want to delete image");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "The image has been deleted.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "There was an error deleting the image.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Saving parameters and resizing images, please wait...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Uploading, please wait...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "The sort order has not been saved. Do you want to save the sort order?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "The image sort order has been saved.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "There was an error saving the image sort.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "The file you are trying to upload is bigger than the 'upload_max_filesize' or the 'post_max_size' PHP settings. Contact your system administrator to increase these limits.");
?>
